==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/EntitlementValuesResponse.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EntitlementValue;
import com.okta.sdk.resource.model.EntitlementValuesResponseLinks;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.openapitools.jackson.nullable.JsonNullable;
import com.fasterxml.jackson.annotation.JsonIgnore;
import org.openapitools.jackson.nullable.JsonNullable;
import java.util.NoSuchElementException;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EntitlementValuesResponse
 */
@JsonPropertyOrder({ EntitlementValuesResponse.JSON_PROPERTY_ENTITLEMENT_VALUES,
        EntitlementValuesResponse.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EntitlementValuesResponse implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENTITLEMENT_VALUES = "entitlementValues";
    private List<EntitlementValue> entitlementValues = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private JsonNullable<EntitlementValuesResponseLinks> links = JsonNullable
            .<EntitlementValuesResponseLinks> undefined();

    public EntitlementValuesResponse() {
    }

    public EntitlementValuesResponse entitlementValues(List<EntitlementValue> entitlementValues) {

        this.entitlementValues = entitlementValues;
        return this;
    }

    public EntitlementValuesResponse addentitlementValuesItem(EntitlementValue entitlementValuesItem) {
        if (this.entitlementValues == null) {
            this.entitlementValues = new ArrayList<>();
        }
        this.entitlementValues.add(entitlementValuesItem);
        return this;
    }

    /**
     * Get entitlementValues
     *
     * @return entitlementValues
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITLEMENT_VALUES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<EntitlementValue> getEntitlementValues() {
        return entitlementValues;
    }

    @JsonProperty(JSON_PROPERTY_ENTITLEMENT_VALUES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntitlementValues(List<EntitlementValue> entitlementValues) {
        this.entitlementValues = entitlementValues;
    }

    public EntitlementValuesResponse links(EntitlementValuesResponseLinks links) {
        this.links = JsonNullable.<EntitlementValuesResponseLinks> of(links);

        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonIgnore

    public EntitlementValuesResponseLinks getLinks() {
        return links.orElse(null);
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public JsonNullable<EntitlementValuesResponseLinks> getLinks_JsonNullable() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    public void setLinks_JsonNullable(JsonNullable<EntitlementValuesResponseLinks> links) {
        this.links = links;
    }

    public void setLinks(EntitlementValuesResponseLinks links) {
        this.links = JsonNullable.<EntitlementValuesResponseLinks> of(links);
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntitlementValuesResponse entitlementValuesResponse = (EntitlementValuesResponse) o;
        return Objects.equals(this.entitlementValues, entitlementValuesResponse.entitlementValues)
                && equalsNullable(this.links, entitlementValuesResponse.links);
        // ;
    }

    private static <T> boolean equalsNullable(JsonNullable<T> a, JsonNullable<T> b) {
        return a == b
                || (a != null && b != null && a.isPresent() && b.isPresent() && Objects.deepEquals(a.get(), b.get()));
    }

    @Override
    public int hashCode() {
        return Objects.hash(entitlementValues, hashCodeNullable(links));
    }

    private static <T> int hashCodeNullable(JsonNullable<T> a) {
        if (a == null) {
            return 1;
        }
        return a.isPresent() ? Arrays.deepHashCode(new Object[] { a.get() }) : 31;
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntitlementValuesResponse {\n");
        sb.append("    entitlementValues: ").append(toIndentedString(entitlementValues)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-21.0.0-sources.jar: com/okta/sdk/resource/model/EntitlementValuesResponse.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.EntitlementValue;
import com.okta.sdk.resource.model.EntitlementValuesResponseLinks;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EntitlementValuesResponse
 */
@JsonPropertyOrder({ EntitlementValuesResponse.JSON_PROPERTY_ENTITLEMENT_VALUES,
        EntitlementValuesResponse.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class EntitlementValuesResponse implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENTITLEMENT_VALUES = "entitlementValues";
    private List<EntitlementValue> entitlementValues = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private EntitlementValuesResponseLinks links;

    public EntitlementValuesResponse() {
    }

    public EntitlementValuesResponse entitlementValues(List<EntitlementValue> entitlementValues) {

        this.entitlementValues = entitlementValues;
        return this;
    }

    public EntitlementValuesResponse addentitlementValuesItem(EntitlementValue entitlementValuesItem) {
        if (this.entitlementValues == null) {
            this.entitlementValues = new ArrayList<>();
        }
        this.entitlementValues.add(entitlementValuesItem);
        return this;
    }

    /**
     * Get entitlementValues
     *
     * @return entitlementValues
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENTITLEMENT_VALUES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<EntitlementValue> getEntitlementValues() {
        return entitlementValues;
    }

    @JsonProperty(JSON_PROPERTY_ENTITLEMENT_VALUES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEntitlementValues(List<EntitlementValue> entitlementValues) {
        this.entitlementValues = entitlementValues;
    }

    public EntitlementValuesResponse links(EntitlementValuesResponseLinks links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public EntitlementValuesResponseLinks getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(EntitlementValuesResponseLinks links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EntitlementValuesResponse entitlementValuesResponse = (EntitlementValuesResponse) o;
        return Objects.equals(this.entitlementValues, entitlementValuesResponse.entitlementValues)
                && Objects.equals(this.links, entitlementValuesResponse.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(entitlementValues, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EntitlementValuesResponse {\n");
        sb.append("    entitlementValues: ").append(toIndentedString(entitlementValues)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
